| Title: | An Interface to the OpenBangsamoro Database |
|---|---|
| Description: | The OpenBangsamoro initiative supports the use of open statistical, geospatial, and administrative data for transparent, accountable, and participatory decision-making as the Autonomous Region in Muslim Mindanao (ARMM) transforms into the Bangsamoro Autonomous Region in Muslim Mindanao. |
| Authors: | Ernest Guevarra [aut, cre] (ORCID: <https://orcid.org/0000-0002-4887-4415>) |
| Maintainer: | Ernest Guevarra <[email protected]> |
| License: | GPL-3 |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-28 08:33:13 UTC |
| Source: | https://github.com/panukatan/openbangsamoro |
Get the OpenBangsamoro Database inventory
bangsa_get_inventory(dataset = c("geospatial", "tabular", "docs", "metadata"))bangsa_get_inventory(dataset = c("geospatial", "tabular", "docs", "metadata"))
dataset |
A string value from either |
A tibble of the specified inventory of various datasets available in the OpenBangsamoro Database.
Ernest Guevarra
## Retrieve the geospatial datasets inventory bangsa_get_inventory(dataset = "geospatial")## Retrieve the geospatial datasets inventory bangsa_get_inventory(dataset = "geospatial")
Get the OpenBangsamoro Database metadata
bangsa_get_metadata()bangsa_get_metadata()
A tibble containing metadata information regarding the OpenBangsamoro Database.
Ernest Guevarra
bangsa_get_metadata()bangsa_get_metadata()
A convenience wrapper to googledrive functions set to specifically access the OpenBangsamoro Google Drive database and list files and folders within.
bangsa_ls(id = "1W8JV4hth_gs1V6efb92HMz0eU2LRYbOO") bangsa_ls_geodata() bangsa_ls_tabular(id = bangsa_ls()$id[bangsa_ls()$name == "2-Tabular Data"]) bangsa_ls_docs( id = bangsa_ls()$id[bangsa_ls()$name == "3-Development Plans, Studies, and Reports"] )bangsa_ls(id = "1W8JV4hth_gs1V6efb92HMz0eU2LRYbOO") bangsa_ls_geodata() bangsa_ls_tabular(id = bangsa_ls()$id[bangsa_ls()$name == "2-Tabular Data"]) bangsa_ls_docs( id = bangsa_ls()$id[bangsa_ls()$name == "3-Development Plans, Studies, and Reports"] )
id |
Character vector of the OpenBangsamoro Google Drive id. This is currently set to 1W8JV4hth_gs1V6efb92HMz0eU2LRYbOO |
A tibble of names and ids of files and folders within the the OpenBangsamoro Google Drive
Ernest Guevarra
bangsa_ls()bangsa_ls()